# -*- coding: utf-8 -*-

from RoadCentre import plugins,project
from menu import Menu,SubMenu
from gui import mainWindow

class DetectorMenu(SubMenu):
    def __init__(self):
        SubMenu.__init__(self, (u'Детектор', u'Детекторы'))
        self.net329 = getattr(plugins,'Net329gPlugin',None)
        self.RcdView = getattr(plugins,'RcdViewPlugin',None)
        if self.net329 and self.RcdView:
            a = self.menuMain.addAction(u'Показания')
            a.connect('triggered()', self.showDt)
            a = self.menuMain.addAction(u'Статистика')
            a.connect('triggered()', self.showDtStat)
            a = self.menuMain.addAction(u'График отбраковки')
            a.connect('triggered()', self.showDtFaults)
            a = self.menuMain.addAction(u'История здоровья')
            a.connect('triggered()', self.showDtHealthHistory)
            if hasattr(plugins, 'Service'):
                a = self.menuMain.addAction(u'Настройка отбраковки')
                a.connect('triggered()', self.dt_setup)

    def tl_detectors(self):
        tl_dt = {}
        for sel in self.selection:
            if sel.inherits('QGraphicsItem'):
                dt = self.net329.item2object(sel)
                if not dt.inherits('Detector') and not dt.inherits('Net329a::Detector'):
                    continue
                granule = dt.granule
                if not granule or granule.tlId <= 0:
                    continue
                if granule.tlId not in tl_dt:
                    tl_dt[granule.tlId] = [dt.tlId]
                else:
                    tl_dt[granule.tlId].append(dt.tlId)
            else:
                tl_id = getattr(sel,'ownerId',None)
                dt_id = getattr(sel,'id',None)
                if tl_id is not None and dt_id is not None:
                    if tl_id not in tl_dt:
                        tl_dt[tl_id] = [dt_id]
                    else:
                        tl_dt[tl_id].append(dt_id)
                
        return tl_dt

    def showDt(self):
        createWidget = self.RcdView.createDtWidget
        for tl_id,dt_list in self.tl_detectors().items():
            if len(dt_list)==0:
                continue
            wnd = createWidget(tl_id, dt_list)
            wnd.show()

    def showDtStat(self):
        createWidget = self.RcdView.createDtStatWidget
        for tl_id,dt_list in self.tl_detectors().items():
            if len(dt_list)==0:
                continue
            wnd = createWidget(tl_id, dt_list)
            wnd.show()

    def showDtFaults(self):
        createWidget = self.RcdView.createDtFaultsView
        for tl_id,dt_list in self.tl_detectors().items():
            for dt_id in dt_list:
                wnd = createWidget(tl_id, dt_id)
                wnd.show()

    def dt_setup(self):
        createWidget = self.RcdView.createDtFaultsView
        from service import createDtSetupWidget
        for tl_id,dt_list in self.tl_detectors().items():
            for dt_id in dt_list:
                w = plugins.Service.createDtSetupWidget(tl_id, dt_id, plugins.RcdViewPlugin.database(), createDtSetupWidget.rcd_rpc)
                w.windowTitle = u'Настройка отбраковки для дт %d-%d' % (tl_id, dt_id)
                w.show()

    def showDtHealthHistory(self):
        createWidget = self.RcdView.createDtHealthHistoryView
        for tl_id,dt_list in self.tl_detectors().items():
            for dt_id in dt_list:
                wnd = createWidget(tl_id, dt_id)
                wnd.show()


class RouteMenu(SubMenu):
    def __init__(self):
        SubMenu.__init__(self, (u'Маршрут', u'Маршруты'))
        self.net329 = getattr(plugins,'Net329gPlugin',None)
        self.timeline = getattr(plugins,'TimelinePlugin',None)
        if self.net329 and self.timeline:
            a = self.menuMain.addAction(u'Лента времени')
            a.connect('triggered()', self.showTimeline)
            a = self.menuMain.addAction(u'Лента времени (архив)')
            a.connect('triggered()', self.showArchiveTimeline)

    def selectedRoutes(self):
        for sel in self.selection:
            r = self.net329.item2object(sel)
            if r and r.inherits('Net329a::Route'):
                yield r

    def showTimeline(self):
        for r in self.selectedRoutes():
            showTimeline(r, False)
            break

    def showArchiveTimeline(self):
        for r in self.selectedRoutes():
            showTimeline(r, True)
            break

def showTimeline(route, archive):
    from timeline import docTimelineWidget, findSynchronizerForTimeline
    timeline_data = plugins.Net329gPlugin.getTimelineData(route)
    doc_window = plugins.TimelinePlugin.createTimelineWidget(mainWindow, route.id, timeline_data, archive)
    tlw = doc_window.findChild('TimelineWidget')
    findSynchronizerForTimeline(tlw)
    tl_list = []
    for oid in tlw.getRoutesTlId():
        light = project.object(oid)
        if light is not None:
            tl_list.append(light)
    tlw.setRoutesTl(tl_list)
    tlw.start()
    docTimelineWidget(doc_window)

def show_settings_dialog():
    if not hasattr(plugins, 'Net329gPlugin'):
        return
    from gui import mainWindow
    plugins.Net329gPlugin.showSettingsDialog(mainWindow)
